|travis-master| |coverall-master| |doc-master| |pypi-downloads| |pypi-lastrelease| |python-versions|
|project-status| |project-license| |project-format| |project-implementation|

.. |travis-master| image:: https://travis-ci.org/alfred82santa/telebot.svg?branch=master
    :target: https://travis-ci.org/alfred82santa/aiotelebot

.. |coverall-master| image:: https://coveralls.io/repos/alfred82santa/telebot/badge.svg?branch=master&service=github
    :target: https://coveralls.io/r/alfred82santa/aiotelebot?branch=master

.. |doc-master| image:: https://readthedocs.org/projects/aiotelebot/badge/?version=latest
    :target: http://aiotelebot.readthedocs.io/?badge=latest
    :alt: Documentation Status

.. |pypi-downloads| image:: https://img.shields.io/pypi/dm/aiotelebot.svg
    :target: https://pypi.python.org/pypi/aiotelebot/
    :alt: Downloads

.. |pypi-lastrelease| image:: https://img.shields.io/pypi/v/aiotelebot.svg
    :target: https://pypi.python.org/pypi/aiotelebot/
    :alt: Latest Version

.. |python-versions| image:: https://img.shields.io/pypi/pyversions/aiotelebot.svg
    :target: https://pypi.python.org/pypi/aiotelebot/
    :alt: Supported Python versions

.. |project-status| image:: https://img.shields.io/pypi/status/aiotelebot.svg
    :target: https://pypi.python.org/pypi/aiotelebot/
    :alt: Development Status

.. |project-license| image:: https://img.shields.io/pypi/l/aiotelebot.svg
    :target: https://pypi.python.org/pypi/aiotelebot/
    :alt: License

.. |project-format| image:: https://img.shields.io/pypi/format/aiotelebot.svg
    :target: https://pypi.python.org/pypi/aiotelebot/
    :alt: Download format

.. |project-implementation| image:: https://img.shields.io/pypi/implementation/aiotelebot.svg
    :target: https://pypi.python.org/pypi/aiotelebot/
    :alt: Supported Python implementations


====================
aioTelebot Framework
====================

**Unofficial Telegram Bot SDK for Python 3.5+**


Telegram bot framework using Python asyncio
